CLI-Plug-in für Katalogverwaltung
Die Befehlszeilenschnittstelle (CLI) der IBM Cloud® Katalogverwaltung bietet zusätzliche Funktionen für die Arbeit mit den Produkten im IBM Cloud Katalog und den privaten Katalogen in Ihrem Konto. Mit diesem Plug-in der Befehlszeilenschnittstelle können Sie private Kataloge verwalten, private Softwareprodukte integrierten und die Kataloganzeigen des öffentlichen Katalogs und der privaten Kataloge verwalten.
Vorbereitende Schritte
- Installieren Sie die IBM Cloud-Befehlszeilenschnittstelle. Weitere Informationen finden Sie in Einführung in die IBM Cloud-Befehlszeilenschnittstelle. Das Präfix für die Ausführung von Befehlen
über die Befehlszeilenschnittstelle von IBM Cloud lautet
ibmcloud. - Melden Sie sich vor dem Ausführen von Registry-Befehlen mit dem Befehl
ibmcloud loginbei IBM Cloud an, um ein Zugriffstoken zu generieren und Ihre Sitzung zu authentifizieren.
Plug-in für Katalogverwaltung installieren
Führen Sie den folgenden Befehl aus, um das Plug-in für die Katalogverwaltung zu installieren:
ibmcloud plugin install catalogs-management
Sie erhalten über die Befehlszeile entsprechende Benachrichtigungen, wenn Aktualisierungen für die ibmcloud-CLI und das CLI-Plug-in catalogs-management verfügbar sind. Stellen Sie sicher, dass sich Ihre Befehlszeilenschnittstelle
auf dem aktuellsten Stand befindet, damit Sie alle verfügbaren Befehle und Flags verwenden können.
Wenn Sie prüfen möchten, welches Version des CLI-Plug-ins catalogs-management derzeit installiert ist, führen Sie den Befehl ibmcloud plugin list aus.
Aus Datenschutz- und Sicherheitsgründen sollten Sie keine personenbezogenen Daten in Ihren Katalognamen oder -beschreibungen angeben.
ibmcloud catalog konto add-approval-access
Führen Sie den folgenden Befehl aus, um Ihrem Katalogaccount Genehmigungszugriff hinzuzufügen.
ibmcloud catalog account add-approval-access [--account-ids IDS] [--object-kind KIND]
Befehlsoptionen
- --object-kind WERT
- Geben Sie die Objektart an. Die Optionen sind
offering,vpe,proxy_sourceoderpreset_configuration. - --account-ids WERT
- Geben Sie eine durch Komma getrennte Liste von Konto-IDs mit einem der folgenden Präfixe an.
-acct-für normale Konten,-ent-für Unternehmenskonten und-entgrp-für Unternehmenskontogruppen.
ibmcloud catalog konto löschen-freigabe-zugriff
Führen Sie den folgenden Befehl aus, um den Genehmigungszugriff auf Ihr Katalogkonto zu löschen.
ibmcloud catalog account delete-approval-access [--account-ids IDS] [--object-kind KIND]
Befehlsoptionen
- --object-kind WERT
- Geben Sie die Objektart an. Die Optionen sind
offering,vpe,proxy_sourceoderpreset_configuration. - --account-ids WERT
- Geben Sie eine durch Komma getrennte Liste von Konto-IDs mit einem der folgenden Präfixe an.
-acct-für normale Konten,-ent-für Unternehmenskonten und-entgrp-für Unternehmenskontogruppen.
ibmcloud catalog account get-approval-list
Führen Sie den folgenden Befehl aus, um eine Genehmigungsliste für Ihr Katalogkonto zu erhalten.
ibmcloud catalog account get-approval-list [--object-kind KIND]
Befehlsoptionen
- --object-kind WERT
- Geben Sie die Objektart an. Die Optionen sind
offering,vpe,proxy_sourceoderpreset_configuration.
ibmcloud catalog account get-approval-list-source
Führen Sie den folgenden Befehl aus, um alle Zielkonten abzurufen, die auf eine Quelle verweisen.
ibmcloud catalog account get-approval-list-source [--approval-state STATE] [--enterprise-id ID] [--object-kind KIND]
Befehlsoptionen
- --object-kind WERT
- Geben Sie die Objektart an. Die Optionen sind
offering,vpe,proxy_sourceoderpreset_configuration. - --approval-state WERT
- Geben Sie den Genehmigungsstatus an. Optionen sind
approved,pendingoderrejected. - --enterprise-id WERT (fakultativ)
- Geben Sie eine Unternehmens-oder Unternehmenskontogruppen-ID an, um Anforderungen für das Unternehmen anzuzeigen oder zu verwalten. Stellen Sie der ID das Präfix
-ent-für ein Unternehmen und-entgrpfür eine Kontogruppe voran.
ibmcloud catalog account set-approval-state-source
Führen Sie den folgenden Befehl aus, um den Genehmigungsstatus für Zielkonten festzulegen, die auf eine Quelle verweisen.
ibmcloud catalog account set-approval-state-source [--account-ids IDS] [--approval-state STATE] [--enterprise-id ID] [--object-kind KIND]
Befehlsoptionen
- --object-kind WERT
- Geben Sie die Objektart an. Die Optionen sind
offering,vpe,proxy_sourceoderpreset_configuration. - --approval-state WERT
- Geben Sie den Genehmigungsstatus an. Optionen sind
approved,pendingoderrejected. - --account-ids WERT
- Geben Sie eine durch Kommata getrennte Liste von Konto-IDs mit einem der folgenden Präfixe an:
-acct-für normale Konten,-ent-für Unternehmenskonten und-entgrp-für Unternehmenskontogruppen. - --enterprise-id WERT (fakultativ)
- Geben Sie eine Unternehmens-oder Unternehmenskontogruppen-ID an, um Anforderungen für das Unternehmen anzuzeigen oder zu verwalten. Stellen Sie der ID das Präfix
-ent-für ein Unternehmen und-entgrpfür eine Kontogruppe voran.
ibmcloud catalog create
Verwenden Sie diesen Befehl, um einen neuen privaten Katalog in Ihrem Konto zu erstellen. Mit einem privaten Katalog können Sie eine Gruppe von Produkten, von Ihnen hinzugefügte private Produkte oder Referenzen auf Produkte des IBM Cloud-Katalogs verwalten. Damit ein Benutzer die Produkte anzeigen und verwenden kann, muss er über Zugriffsberechtigungen für den privaten Katalog über eine IAM-Zugriffsrichtlinie und die Ressourcengruppe, die den privaten Katalog enthält, verfügen.
Zielen Sie auf eine Ressourcengruppe, um einen Katalog zu erstellen, da der Katalog im Kontext einer bestimmten Ressourcengruppe existiert. Zum Abrufen der Liste mit Ressourcengruppen können Sie den Befehl ibmcloud resource groups und anschließend den Befehl ibmcloud target -g "resource group" ausführen.
ibmcloud catalog create --name CATALOG [--catalog-description "DESCRIPTION"]
Befehlsoptionen
- --name CATALOG
- Der Katalognamen.
- --catalog-description DESCRIPTION (optional)
- Kurze Beschreibung für den neuen Katalog.
Beispiel
Erstellen Sie einen Katalog namens dev-catalog mit der Beschreibung a catalog for development and testing purpsoses:
ibmcloud catalog create --name dev-catalog --catalog-description "a catalog for development and testing purposes"
ibmcloud catalog list
Führen Sie den folgenden Befehl aus, um die Liste der Kataloge in diesem bestimmten Konto abzurufen.
ibmcloud catalog list [--output FORMAT]
Befehlsoptionen
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json.
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Name ID Description Last Updated
dev-catalog 93f592fb-e09b-4a53-bbd9-92f6ab9e253b short-description 2019-11-21 21:28:28.347 +0000 UTC
ABDemoTestCatalog 7a246530-e191-45e2-87cc-07c8c7033d2b short-description 2019-08-19 17:43:48.59 +0000 UTC
ibmcloud catalog get
Führen Sie den folgenden Befehl aus, um Informationen zu einem bestimmten Katalog im Konto abzurufen.
ibmcloud catalog get --catalog CATALOG [--output FORMAT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json.
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Name Current State Version Locator
dev-catalog
|__dev-offering
| |__Openshift
| |__1.0.0 Draft 480fb4e3-d7ba-4e9b-9d4c-42f0ab811040.fd8f91a3-8027-4919-ad6d-c5189a4a8ee
ibmcloud catalog delete
Führen Sie den folgenden Befehl aus, um einen bestimmten Katalog im Konto zu löschen.
ibmcloud catalog delete --catalog CATALOG
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
ibmcloud catalog search
Führen Sie den folgenden Befehl aus, um den öffentlichen Katalog nach veröffentlichten Produkten, z. B. Services und Software, zu durchsuchen.
ibmcloud catalog search <QUERY> [--catalog CATALOG] [--type TYPE] [-r, --region REGION] [-k, --kind KIND] [--fields FIELDS] [-p, --price PRICE] [-t, --tag TAG] [--sort-by PROPERTY] [--col COLUMNS] [--reverse] [--output TYPE] [--global]
Befehlsoptionen
- --type TYPE (optional)
- Optional. Der Standardwert ist
services. Gültige Optionen:servicesundsoftware. - --catalog CATALOG (optional)
- Sucht Software, die von Ihrem Konto veröffentlicht wurde. Geben Sie Namen oder die ID des Katalogs an, der bzw. die für die Suche verwendet werden soll.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Voreinstellung ist Terminal-kompatibel und die einzigen alternativen Optionen sind
jsonundcsv. - --kind KIND (optional)
- Das Kennzeichen ist nur für Suchdienste gültig. Geben Sie eine durch Kommas getrennte Liste mit Produkten an.
- --region REGION (optional)
- Das Kennzeichen ist nur für Suchdienste gültig. Geben Sie eine durch Kommas getrennte Liste mit Regionen an. Führen Sie
ibmcloud cs regionsaus, um eine gültige Liste abzurufen. - --price PRICE (optional)
- Das Kennzeichen ist nur für Suchdienste gültig. Geben Sie eine durch Kommas getrennte Liste mit Preisstrukturtypen an.
- --tag TAG (optional)
- Das Kennzeichen ist nur für Suchdienste gültig. Geben Sie eine durch Kommas getrennte Liste mit Tags an.
- --global (optional)
- Das Kennzeichen ist nur für Suchdienste gültig. Verwenden Sie es, um in einem globalen Bereich zu arbeiten.
- --sort-by TYPE (optional)
- Das Kennzeichen ist nur für Suchdienste gültig und dient der Ordnung des Suchergebnisses. Gültige Optionen:
name,displayname,kind,provider,createdundupdated. - --reverse (optional)
- Das Kennzeichen ist nur für Suchdienste gültig. Verwenden Sie es, um die Sortierreihenfolge umzukehren.
- --fields FIELDS (optional)
- Das Kennzeichen ist nur für Suchdienste gültig. Die Tabelle kann angepasst werden. Beispiel:
--fields name,kind,metadata.service.iam_compatible.
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Name ID Category
2 Zone VPC f10d9ae9-ac94-4718-b24a-3994241ae2a4-global Networking
Apache Qml0bmFtaS1hcGFjaGU=-global Developer Tools
Apache Airflow Qml0bmFtaS1haXJmbG93-global Databases
Apache Airflow Qml0bmFtaS1haXJmbG93-global Developer Tools
ibmcloud catalog filter get
Führen Sie den folgenden Befehl aus, um Filterdetails für das Konto oder aber für einen bestimmten Katalog abzurufen.
ibmcloud catalog filter get --catalog CATALOG [--output FORMAT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --account-group ACCOUNT GROUP
- Der Name oder die ID der Kontogruppe. Dieses Feld ist nur für Unternehmenskonten gültig.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json.
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Account: The IBM Cloud catalog is visible to all users in this account.
Filter:
Including IBM Cloud catalog
Type Include Tags
Pricing plan false Free
Provider false Third Party
ibmcloud catalog filter create
Führen Sie den folgenden Befehl aus, um einen neuen Filter zu erstellen. Falls ein Filter vorhanden ist, wird der aktuelle Filter durch diesen Befehl außer Kraft gesetzt.
ibmcloud catalog filter create [--catalog CATALOG] [--category CATEGORY] [--compliance COMPLIANCE] [--deployment-target TARGET] [--exclude-list LIST] [--include-all ALL] [--include-list LIST] [--offering-format FORMAT] [--pricing-plan PLAN] [--provider PROVIDER] [--release RELEASE] [--type TYPE]
Befehlsoptionen
- --catalog CATALOG (optional)
- Der Name oder die ID des Katalogs. Wenn keine Angabe erfolgt, wird der Filter auf Kontoebene erstellt.
- --account-group ACCOUNT GROUP
- Der Name oder die ID der Kontogruppe. Diese Option ist nur für Unternehmenskonten gültig.
- --hide-ibm-catalog (optional)
- Standardmäßig ist der Katalog für alle Benutzer in diesem Konto sichtbar. Durch Angabe dieses Flags können Sie Produkte nur für die von Ihnen ausgewählten Benutzer verfügbar machen, indem Sie die Sichtbarkeit gegenüber dem IBM Cloud-Katalog inaktivieren und die Produkte zu Ihren privaten Katalogen hinzufügen.
- --include-all BOOLEAN (optional)
- Die Vorgabe ist true, wenn das Flag nicht angegeben wird. Gültige Werte sind
trueundfalse. Wird der Wert 'true' festgelegt, bezieht der Filter standardmäßig den gesamten öffentlichen Katalog ein und nachfolgende Filter werden ausgeschlossen. Wird der Wert 'false' festgelegt, schließt der Filter den gesamten öffentlichen Katalog aus und nachfolgende Flags werden einbezogen. Weitere Informationen finden Sie unter Katalogeinstellungen verwalten.
--offering-format FORMAT (optional)
- --category CATEGORY (optional)
- Geben Sie die Kategorie an, die am besten für die Verwendung Ihres Produkts durch Benutzer geeignet ist. Mithilfe von Kategorien werden Produkte im Katalog anhand allgemeiner Lösungen, Funktionen oder Einsatzbereiche organisiert. Sie können
nur eine Kategorie auswählen. Mit
ibmcloud catalog offering category-optionskönnen alle Optionen angezeigt werden. Der Standardwert istDeveloper tools. - --compliance TYPE (optional)
- Geben Sie eine durch Kommas getrennte Liste von Compliance-Kategorien an, die einbezogen oder ausgeschlossen werden sollen. Mit
ibmcloud catalog filter optionskönnen alle Optionen angezeigt werden. - --deployment-target TARGET (optional)
- Geben Sie eine durch Kommas getrennte Liste mit Bereitstellungszielen an, die einbezogen oder ausgeschlossen werden sollen. Mit
ibmcloud catalog filter optionskönnen alle Optionen angezeigt werden. - --exclude-list LIST (optional)
- Ermöglicht die Angabe einer durch Kommas getrennten Liste mit Produkt-IDs oder -Namen, die aus dem gefilterten öffentlichen Katalog ausgeschlossen werden müssen.
- --include-list LIST (optional)
- Ermöglicht die Angabe einer durch Kommas getrennten Liste mit Produkt-IDs oder -Namen, die in den gefilterten öffentlichen Katalog einbezogen werden müssen.
- Geben Sie eine durch Kommas getrennte Liste mit Produktformaten an, die einbezogen oder ausgeschlossen werden sollen. Mit
ibmcloud catalog filter optionskönnen alle Optionen angezeigt werden. - --pricing-plan PLAN (options)
- Geben Sie eine durch Kommas getrennte Liste mit Preistarifen an, die einbezogen oder ausgeschlossen werden sollen. Mit
ibmcloud catalog filter optionskönnen alle Optionen angezeigt werden. - --provider PROVIDER (optional)
- Geben Sie eine durch Kommas getrennte Liste der Provider an, die einbezogen oder ausgeschlossen werden sollen. Mit
ibmcloud catalog filter optionskönnen alle Optionen angezeigt werden. - --release RELEASE (optional)
- Geben Sie eine durch Kommas getrennte Liste der Kategorien an, die einbezogen oder ausgeschlossen werden sollen. Mit
ibmcloud catalog filter optionskönnen alle Optionen angezeigt werden. - --type TYPE (optional)
- Geben Sie eine durch Kommas getrennte Liste der Softwaretypen an, die einbezogen oder ausgeschlossen werden sollen. Mit
ibmcloud catalog filter optionskönnen alle Optionen angezeigt werden.
ibmcloud catalog filter delete
Führen Sie den folgenden Befehl aus, um einen angewendeten Filter zu löschen. Dieser gilt standardmäßig auf Kontoebene, es sei denn, es ist ein Katalog angegeben. Der Filter wird hiermit zurückgesetzt, sodass alle Produkte des öffentlichen Katalogs einbezogen werden.
ibmcloud catalog filter delete --catalog CATALOG
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --account-group ACCOUNT GROUP
- Der Name oder die ID der Kontogruppe. Diese Option ist nur für Unternehmenskonten gültig.
ibmcloud catalog filter offering
Sie können den Filter aktualisieren, um ein bestimmtes Produkt und gültige Preisstrukturpläne einzubeziehen oder auszuschließen. Dieser gilt standardmäßig auf Kontoebene, es sei denn, es ist ein Katalog oder eine Kontogruppe angegeben.
ibmcloud catalog filter offering --offering PRODUCT-NAME
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --account-group ACCOUNT GROUP
- Der Name oder die ID der Kontogruppe. Diese Option ist nur für Unternehmenskonten gültig.
- --plans-list PLANS LIST
- Eine durch Kommas getrennte Liste mit Plan-IDs oder -Namen, die einbezogen oder ausgeschlossen werden sollen.
- --offering OFFERING
- Der Name oder die ID des Produkts.
- --include
- Der Standardwert lautet 'true', falls kein Flag angegeben wird. Gültige Werte sind
trueundfalse. Wird der Wert 'true' festgelegt, sind das angegebene Produkt und die angegebenen Pläne für die Benutzer im Konto sichtbar. Wird der Wert 'false' festgelegt, sind das Produkt und die Pläne für Benutzer im Konto nicht sichtbar.
ibmcloud catalog filter hide-ibm-public-catalog
Standardmäßig ist der IBM Cloud-Katalog für alle Benutzer im Konto sichtbar. Sie können Produkte nur für ausgewählte Benutzer verfügbar machen, indem Sie ihre Sichtbarkeit im IBM Cloud-Katalog ausschalten und die Produkte in Ihren privaten Katalogen hinzufügen.
ibmcloud catalog filter hide-ibm-public-catalog
ibmcloud catalog filter show-ibm-public-catalog
Standardmäßig ist der IBM Cloud-Katalog für alle Benutzer im Konto sichtbar. Sie können Produkte nur für ausgewählte Benutzer verfügbar machen, indem Sie ihre Sichtbarkeit im IBM Cloud-Katalog ausschalten und die Produkte in Ihren privaten Katalogen hinzufügen.
ibmcloud catalog filter show-ibm-public-catalog
ibmcloud catalog filter options
Führen Sie den folgenden Befehl aus, um die Filteroptionen für jede Filterkategorie abzurufen.
ibmcloud catalog filter options
Befehlsoptionen
- --all
- Schließt Branche, Lösungstyp und Preistarif in die Liste der Filter ein.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json.
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Deployment target ID
IBM Cloud Kubernetes Service target_iks
IBM Cloud Schematics target_terraform
Red Hat OpenShift target_roks
VMware vCenter Server target_vcenter
Virtual private cloud target_vpc-x86
Power Systems Virtual Server target_power-iaas
Provider ID
Third party ibm_third_party
Community ibm_community
IBM ibm_created
Release ID
Beta ibm_beta
Deprecated ibm_deprecated
Works with ID
SAP Certified sap_certified
Quantum Technologies quantum_tech
Satellite Enabled satellite_enabled
HPC hpc
Support ID
Third party supported support_third_party
Community supported support_community
IBM supported support_ibm
Delivery method ID
Cloud Paks cloud_pak
Helm charts helm
Operators operator
OVA Images ova
Starter kits template
Terraform terraform
Server Images vsi_image
Blueprint blueprint
Toolchains toolchain
Compliance ID
EU Supported eu_access
Financial Services Validated fs_ready
HIPAA Enabled hipaa
IAM-enabled rc_compatible
Service Endpoint Supported service_endpoint_supported
Category ID Tags
Compute compute compute,compute_classic,content,openwhisk,runtime,virtualservers,compute_baremetal
Containers containers containers,clusters,registry
Networking network network,network_vpc,network_classic,network_edge,network_interconnectivity
Storage storage storage,storage_vpc,storage_classic,storage_datamovement
Converged infrastructure converged_infra converged_infra
Enterprise applications enterprise_app enterprise_app
AI / Machine Learning ai watson,ai
Analytics analytics data_analytics,business_analytics,analytics
Blockchain blockchain blockchain
Databases databases data_management,database
Developer tools devops dev_ops
Logging and monitoring logging_monitoring logging_monitoring
Migration migration_tools migration_tools
Integration integration integration,api
Internet of Things iot internet_of_things
Security security security
Mobile mobile mobile,web_and_app
ibmcloud catalog offering create
Führen Sie den folgenden Befehl aus, um ein Produkt zu einem privaten Katalog im Konto hinzuzufügen.
ibmcloud catalog offering create [--catalog CATALOG_NAME] [--zipurl URL] [--include-config] [--target-version VERSION] [--token TOKEN] [--vpc-body BODY]
Befehlsoptionen
- --catalog CATALOG_NAME
- Der Name oder die ID des Katalogs.
- --zipurl URL (fakultativ)
- URL der ZIP-Datei mit dem Produkt.
- --target-version VERSION
- Geben Sie die Version des Produkts an.
- --include-config (optional)
- Wird diese Option angegeben, werden alle Konfigurationswerte einbezogen und sind beim Hinzufügen des Produkts verfügbar.
- --token TOKEN (optional)
- Geben Sie das persönliche Zugriffstoken für ein privates Repository an.
- --vpc-body BODY (fakultativ)
- Geben Sie die Informationen zum Importieren eines virtuellen Server-Image für VPC an, einschließlich Name, Bezeichnung, Installationsart, Zielart, Version, sha, Tags und Metadaten.
Beispiel für ein virtuelles Server-Image für VPC #1
Ein virtuelles Server-Image für VPC als Angebot in einen Katalog mit der ID 51c9e0db-2911-45a6-adb0-ac5332d27cf2 importieren.
ibmcloud catalog offering create --catalog 51c9e0db-2911-45a6-adb0-ac5332d27cf2 --vpc-body '{
"name": "virtual-server-image",
"label": "virtual server image",
"install_kind": "instance",
"target_kinds": ["vpc-x86"],
"version": "0.0.10",
"sha": "64245e5f3f1e9c4048b18db3abd1450d4b6f9e263ac1b33df6fc1ae96fcbdebb",
"tags": ["virtualservers"],
"metadata": {
"operating_system": {
"dedicated_host_only": false,
"vendor": "CentOS",
"name": "centos-7-amd64",
"href": "https://us-south-stage01.iaasdev.cloud.ibm.com/v1/operating_systems/centos-7-amd64",
"display_name": "CentOS 7.x - Minimal Install (amd64)",
"family": "CentOS",
"version": "7.x - Minimal Install",
"architecture": "amd64"
},
"minimum_provisioned_size": 100,
"file": {
"size": 1
},
"images": [{"id": "r134-14903434-faf0-4a66-b861-7b35198de393", "name": "virtual-server-image", "region": "us-south"}]
}
}'
Beispiel für ein virtuelles Server-Image für VPC #2
Ein virtuelles Server-Image für VPC als Angebot in einen Katalog mit der ID 2bdc3974-dfcf-4711-b298-cd238f7d3734 importieren.
ibmcloud catalog offering create --catalog 2bdc3974-dfcf-4711-b298-cd238f7d3734 --vpc-body '{
"name": "virtual-server-image-s390x",
"label": "virtual-server-image-s390x",
"install_kind": "instance",
"target_kinds": ["vpc-z"],
"version": "0.0.10",
"sha": "4739f1eaeeebc69ad5d48f9191fcc0d23960cb720bb16c67e915e5556c1da9b2",
"tags": ["virtualservers"],
"metadata": {
"operating_system": {
"dedicated_host_only": false,
"vendor": "SUSE Linux Enterprise Server",
"name": "sles-15-sp2-s390x-byol",
"href": "https://us-south-stage01.iaasdev.cloud.ibm.com/v1/operating_systems/sles-15-s390x",
"display_name": "Suse enterprise server(s390x)",
"family": "SUSE",
"version": "15-sp2",
"architecture": "s390x"
},
"minimum_provisioned_size": 100,
"file": {
"size": 1
},
"images": [{"id": "r134-f20e2e4e-3133-423c-afa2-365afa14c4dc", "name": "virtual-server-image-s390x", "region": "us-south"}]
}
ibmcloud catalog offering list
Führen Sie den folgenden Befehl aus, um Details zu den Produkten in den privaten Katalogen abzurufen. Mit diesem Befehl haben Sie die Möglichkeit, nach privatem Katalog, Produkt und Version zu filtern.
ibmcloud catalog offering list [--catalog CATALOG] [--offering OFFERING_NAME] [--version VERSION] [--output FORMAT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Der Standard ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON, zum Beispiel
--output json.
Beispiel
Rufen Sie eine Liste aller Produkte ab, die sich im Katalog dev-catalog befinden:
ibmcloud catalog offering list --catalog dev-catalog
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Name ID Current State Version Locator
Cloud Pak for Automation cb90274e-398b-4373-9b28-d6428d3302df
|__OpenShift
|__19.0.2 New 7b7e590f-259b-437b-b1f4-39e8615ed837.21d1d712-80ab-4318-9d05-73c6caaaee23
Cloud Pak for Data 8993c7b1-1794-4447-9275-db83faa08ee4
|__OpenShift
|__2.1.0.2 New 7b7e590f-259b-437b-b1f4-39e8615ed837.ab6ba56f-788d-4d6b-b880-a1001fca8451
harbor 927adb44-6784-4bec-a771-f639900f07f1
|__Kubernetes
|__1.9.1 New 7b7e590f-259b-437b-b1f4-39e8615ed837.e437b06c-273f-49de-8c44-f55e408abf78
IBM Starter Collection for Openshift fd1857f4-cf17-4e97-9443-b615bc71f6a0
|__OpenShift
|__0.0.1 New 7b7e590f-259b-437b-b1f4-39e8615ed837.72e0f636-9dc4-49ae-b3c2-7a5de90487b9
tf_cloudless_sleepy-2.0 c260a67a-1b25-49fc-9896-46e7e6212990
|__
|__1.0.0 New 7b7e590f-259b-437b-b1f4-39e8615ed837.965df91d-5760-4872-adf6-4019796c06b0
|__1.0.1 New 7b7e590f-259b-437b-b1f4-39e8615ed837.aff4cecb-4c9b-41ba-ae3d-71f4217dc0bc
ibmcloud catalog offering search
Führen Sie den folgenden Befehl aus, um Details zu den Produkten in den privaten Katalogen abzurufen. Mit diesem Befehl haben Sie die Möglichkeit, nach privatem Katalog, Produkt und Version zu filtern.
ibmcloud catalog offering search [--catalog CATALOG] [--offering OFFERING_NAME] [--version VERSION] [--output FORMAT]
Befehlsoptionen
- --catalog CATALOG (optional)
- Der Name oder die ID des Katalogs.
- --offering OFFERING (optional)
- Der Name oder die ID des Produkts.
- --version VERSION (optional)
- Der Versionsname oder die ID.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Der Standard ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON, zum Beispiel
--output json.
Beispiel
Rufen Sie eine Liste aller Produkte ab, die sich im Katalog dev-catalog befinden:
ibmcloud catalog offering list --catalog dev-catalog
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Name Current State Version Locator
dev-catalog
|__dev-offering
| |__Kubernetes
| |__1.0.0 Validated b636d651-8489-4425-bd6a-f30af1603577.17ac792e-a603-4f1a-a1b6-48e90a46940c
|__dev-offering-2.0
| |__Kubernetes
| |__1.0.0 Published to account b636d651-8489-4425-bd6a-f30af1603577.decdb0e1-46d2-401a-b482-80f9d6855f98
ibmcloud catalog offering get
Führen Sie den folgenden Befehl aus, um Details zu einem bestimmten Produkt im Katalog abzurufen.
ibmcloud catalog offering get --catalog CATALOG --offering OFFERING_NAME [--output FORMAT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING_NAME
- Der Name oder die ID des Produkts.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Der Standard ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON, zum Beispiel
--output json.
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Name Current State Version Locator
dev-offering
|__
|__1.0.0 Draft 480fb4e3-d7ba-4e9b-9d4c-42f0ab811040.a92f5409-ebd9-413c-88ae-7ed311c1b793
ibmcloud catalog offering import-version
Führen Sie den folgenden Befehl aus, um eine neue Version eines Produkts in den privaten Katalog zu importieren.
ibmcloud catalog offering import-version --catalog CATALOG --offering OFFERING_NAME [--zipurl URL] [--target-version APP_VERSION] [--include-config] [--vpc-body BODY]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING_NAME
- : Der Name oder die ID des Produkts.
- --zipurl URL (fakultativ)
- Die URL verweist auf die.zip-Datei des Produkts.
- --target-version APP_VERSION (optional)
- Die Anwendungsversion der "tgz"-Datei, die importiert wird.
- --include-config (optional)
- Wird diese Option angegeben, werden alle Konfigurationswerte einbezogen und sind beim Importieren der neuen Version verfügbar.
- --vpc-body BODY (fakultativ)
- Geben Sie die Informationen zum Importieren eines virtuellen Server-Image für VPC an, einschließlich Name, Bezeichnung, Installationsart, Zielart, Version, sha, Tags und Metadaten.
Virtuelles Server-Image für VPC Beispiel
Importieren Sie ein virtuelles Server-Image für VPC in ein bestehendes Angebot mit einem Katalog mit ID 51c9e0db-2911-45a6-adb0-ac5332d27cf2 und Angebots-ID 97cdaf1b-62b2-48e2-8589-10b31023866d.
ibmcloud catalog offering import-version --catalog 51c9e0db-2911-45a6-adb0-ac5332d27cf2 --offering 97cdaf1b-62b2-48e2-8589-10b31023866d --vpc-body '{
"name": "virtual-server-image",
"label": "virtual server image",
"install_kind": "instance",
"target_kinds": ["vpc-x86"],
"version": "0.0.10",
"sha": "64245e5f3f1e9c4048b18db3abd1450d4b6f9e263ac1b33df6fc1ae96fcbdebb",
"tags": ["virtualservers"],
"metadata": {
"operating_system": {
"dedicated_host_only": false,
"vendor": "CentOS",
"name": "centos-7-amd64",
"href": "https://us-south-stage01.iaasdev.cloud.ibm.com/v1/operating_systems/centos-7-amd64",
"display_name": "CentOS 7.x - Minimal Install (amd64)",
"family": "CentOS",
"version": "7.x - Minimal Install",
"architecture": "amd64"
},
"minimum_provisioned_size": 100,
"file": {
"size": 1
},
"images": [{"id": "r134-14903434-faf0-4a66-b861-7b35198de393", "name": "virtual-server-image", "region": "us-south"}]
}
}''
ibmcloud catalog offering update
Um ein Produkt in Ihrem privaten Katalog zu aktualisieren, müssen Sie zuerst das Produkt erhalten und können es dann aktualisieren.
Führen Sie den Befehl offering get aus. Weitere Informationen finden Sie auf der Website ibmcloud-Katalogangebot erhalten.
ibmcloud catalog offering get -c <CATALOGID> -o <OFFERINGID> --output json
Führen Sie den Befehl offering update aus.
ibmcloud catalog offering update -c <CATALOGID> -o <OFFERINGID> --updated-offering <UPDATED_OFFERING.json>
ibmcloud catalog offering version preinstall
Führen Sie den folgenden Befehl aus, um das Vorinstallationsscript für ein bestimmtes Produkt auszuführen.
ibmcloud catalog offering version preinstall --version-locator VERSION_NUMBER --cluster CLUSTER_ID --namespace NAME
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für dieses Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt und die Version suchen, die Sie verwenden möchten. - --cluster CLUSTER_ID
- Geben Sie die Cluster-ID des Clusters an, in dem dieses Produkt installiert werden soll.
- --namespace NAME
- Geben Sie den Namensbereich an, den Sie verwenden möchten. Bei Bedarf können Sie einen neuen angeben, welcher dann im Rahmen der Installationsvorbereitung automatisch erstellt wird.
Beispiel
Führen Sie das Vorinstallationsscript für ein Produkt mit der Versionsverweisnummer b636d651-8489-4425-bd6a-f30af1603577.18aad484-c78b-4269-808b-52027621abd4 auf dem Cluster mit der ID bn5ebho206o7fg45f2e0 im Namensbereich
test-namespaceaus:
ibmcloud catalog offering version preinstall --version-locator b636d651-8489-4425-bd6a-f30af1603577.18aad484-c78b-4269-808b-52027621abd4 --cluster bn5ebho206o7fg45f2e0 --namespace test-namespace
ibmcloud catalog offering version preinstall-status
Führen Sie den folgenden Befehl aus, um den Status einer laufenden Vorinstallation abzurufen.
ibmcloud catalog offering version preinstall-status --version-locator VERSION_NUMBER --cluster CLUSTER_ID --namespace NAME [--output FORMAT]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt und die Version suchen, die Sie verwenden möchten. - --cluster CLUSTER_ID
- Geben Sie die Cluster-ID des Clusters an, in dem die Vorinstallation ausgeführt wurde.
- --namespace NAME
- Geben Sie den Namensbereich an, der für die Vorinstallation verwendet wurde.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Der Standard ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON, zum Beispiel
--output json.
ibmcloud catalog offering version validate
Führen Sie den folgenden Befehl aus, um eine neue Version eines Produkts in Ihren privaten Katalog zu validieren. Bevor Produkte im Konto veröffentlicht werden können, damit andere Benutzer eine Instanz aus dem privaten Katalog erstellen können, müssen Angebote validiert werden, um sicherzustellen, dass sie erwartungsgemäß funktionieren.
ibmcloud catalog offering version validate --version-locator VERSION_NUMBER --cluster CLUSTER_ID --namespace NAME [--timeout TIMEOUT] [--wait WAIT] [--override-values VALUES|FILENAME] [--workspace-tf-version VERSION] [--workspace-region REGION] [--workspace-rg-id ID][--schematics-destroy][--schematics-delete]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt und die Version suchen, die Sie verwenden möchten. - --cluster CLUSTER_ID
- Geben Sie die Cluster-ID des Clusters an, in dem dieses Produkt installiert werden soll.
- --namespace NAME
- Geben Sie den Namensbereich an, den Sie verwenden möchten. Bei Bedarf können Sie einen neuen angeben, welcher dann im Rahmen der Installationsvorbereitung automatisch erstellt wird.
- --timeout TIMEOUT
- Geben Sie an, wie viele Sekunden der Arbeitsbereich Schematics auf die Installation wartet. Der Standardwert ist
180. - --wait WAIT
- Warten Sie und verfolgen Sie den Fortschritt des Arbeitsbereichsjobs Schematics. Wenn der Wert
trueangegeben ist, wird mit der Installation gewartet. Wennfalseangegeben ist, wird die Software sofort installiert. Der Standardwert isttrue. - --override-values VALUES|FILENAME (optional)
- Geben Sie alle angepassten Konfigurationswerte für die Installation an. Sie können diesen Wert entweder in einer Zeile oder anhand einer JSON- oder TXT-Datei angeben. Beispiel:
override-values values.json. Beim Validieren eines virtuellen Server-Image für VPC müssen die folgenden Felder angegeben werden: vsi_instance_name, vsi_id, vpc_profile, subnet_id, vpc_id, subnet_zone, ssh_key_id, vpc_region - --workspace-tf-version VERSION (optional)
- Geben Sie eine Terraform-Version des Arbeitsbereichs an.
- --workspace-region REGION (optional)
- Geben Sie eine Arbeitsbereichsregion an.
- --workspace-rg-id ID (optional)
- Geben Sie eine Ressourcengruppen-ID für den Arbeitsbereich an.
- --schematics-destroy (optional)
- Geben Sie dieses Kennzeichen an, um die Arbeitsbereichsressourcen nach der Validierung und Installation zu löschen.
- --schematics-delete VALUE (optional)
- Geben Sie dieses Flag an, um den Arbeitsbereich Schematics nach der Validierung und Installation zu löschen.
Beispiel für die Validierung eines Produkts, das einen Cluster verwendet
Sie validieren ein Produkt mit dem Versionshinweis b636d651-8489-4425-bd6a-f30af1603577.18aad484-c78b-4269-808b-52027621abd4 in einem Cluster mit der ID bn5ebho206o7fg45f2e0 in einem Namensbereich test-namespace.
Da diese Installation angepasste Konfigurationswerte besitzt, werden die entsprechenden Werte in einer Datei values.json angegeben.
ibmcloud catalog offering version validate --version-locator b636d651-8489-4425-bd6a-f30af1603577.18aad484-c78b-4269-808b-52027621abd4 --cluster bn5ebho206o7fg45f2e0 --namespace test-namespace --override-values values.json
Beispielformat für Überschreibungswerte in der Datei values.json:
{
"username": "provision-test-1",
"password": "passw0rd"
}
Virtuelles Server-Image für VPC Beispiel
Überprüfen Sie ein Produkt mit dem Versionslocator 51c9e0db-2911-45a6-adb0-ac5332d27cf2.ecebffdc-f1f8-4a85-965f-9cbe31920542 in einer VPC mit der ID r134-476cbb67-a6c2-4957-9806-3fcbac3498be.
ibmcloud catalog offering version validate --version-locator 51c9e0db-2911-45a6-adb0-ac5332d27cf2.ecebffdc-f1f8-4a85-965f-9cbe31920542 --workspace-region=us-south --workspace-rg-id Default --override-values '{
"vsi_instance_name": "instance-name-1",
"vsi_id": "r134-14903434-faf0-4a66-b861-7b35198de393",
"vpc_profile": "bx2-2x8",
"subnet_id": "0716-d799c449-466c-4844-902c-a5d3f8948d7d",
"vpc_id": "r134-476cbb67-a6c2-4957-9806-3fcbac3498be",
"subnet_zone": "us-south-1",
"ssh_key_id": "r134-0c53e7f2-771f-4d0e-a19e-39f2e6e6949c",
"vpc_region": "us-south"
}
ibmcloud catalog offering version validate-status
Führen Sie den folgenden Befehl aus, um den Status einer laufenden Vorinstallation abzurufen.
ibmcloud catalog offering version validate-status --version-locator VERSION_NUMBER [--output FORMAT]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten. - --output FORMAT (optional)
- Gibt das Ausgabeformat an. Der Standard ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON, zum Beispiel
--output json.
ibmcloud catalog offering category-options
Führen Sie den folgenden Befehl aus, um die Liste der zur Auswahl stehenden Kategorien abzurufen.
ibmcloud catalog offering category-options [--output FORMAT]
Befehlsoptionen
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Der Standard ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON, zum Beispiel
--output json.
Beispiel
ibmcloud catalog offering category-options
Ausgabe
Der Befehl gibt die folgende Ausgabe zurück:
Name Tags Description
VPC Infrastructure vpc Fully customizable, software-defined virtual network with superior isolation.
Compute compute,content,containers,openwhisk,vmware,runtime Build your virtual environments
Containers containers,clusters,registry Get started by creating a Kubernetes cluster, or manage your Docker images in the registry.
Networking network Order network.
Storage storage Order storage.
ibmcloud catalog offering add-category
Führen Sie den folgenden Befehl aus, um einen Kategorietag zu einem Produkt hinzuzufügen. Sie können den Namen der Kategorie angeben, den Sie durch Ausführen des Befehls ibmcloud catalog offering category-options ermitteln können.
Die Produkte müssen sich in einer Kategorie befinden, damit sie sichtbar sind und im Katalog angezeigt werden. Der Standardwert ist Developer tools.
ibmcloud catalog offering category-options [--output FORMAT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
- --category CATEGORY
- Geben Sie die Kategorie an, die am besten für die Verwendung Ihres Produkts durch Benutzer geeignet ist. Mithilfe von Kategorien werden Produkte im Katalog anhand allgemeiner Lösungen, Funktionen oder Einsatzbereiche organisiert. Sie können
nur eine Kategorie auswählen. Mit
ibmcloud catalog offering category-optionskönnen alle Optionen angezeigt werden. Der Standardwert istDeveloper tools.
Beispiel
ibmcloud catalog offering add-category --catalog dev-catalog --offering dev-offering --category dev_ops
Angebotskategorien des ibmcloud-Katalogs
Führen Sie den folgenden Befehl aus, um die Kategorie einer Produktversion abzurufen.
ibmcloud catalog offering version categories [--catalog CATALOG] [--offering OFFERING] [--output OUTPUT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
- --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json.
Beispiel
Rufen Sie die Kategorie eines Produkts mit dem Namen dev-offering ab, das sich in dev-catalog befindet.
ibmcloud catalog offering version categories --catalog dev-catalog --offering dev-offering
ibmcloud catalog offering version get-claims
Führen Sie den folgenden Befehl zum Abrufen der Sicherheits-und Konformitätsinformationen aus, die von einer Version angefordert wurden.
ibmcloud catalog offering version get-claims [--output OUTPUT] [--version-locator LOCATOR]
Befehlsoptionen
- --version-locator LOCATOR
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten. - --output Wert (optional)
- Gibt das Ausgabeformat an. Der Standard ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON, zum Beispiel
--output json.
ibmcloud-Katalog bietet Version Update-Forderungen
Führen Sie den folgenden Befehl aus, um die Sicherheits- und Konformitätsansprüche einer Version zu aktualisieren.
ibmcloud catalog offering version update-claims [--claims CLAIMS] [--version-locator LOCATOR]
Befehlsoptionen
- --claims ANSPRÜCHE
- Geben Sie die Anspruchsdaten für eine Version als JSON-Objekt oder -Datei an.
- --version-locator LOCATOR
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten.
ibmcloud catalog offering version scc-apply
Führen Sie den folgenden Befehl aus, um Ihrer Version einen Security and Compliance Center-Scan hinzuzufügen. Fügen Sie Sicherheits- und Konformitätsinformationen zu Ihrer Version hinzu und validieren Sie Ihre Version, bevor Sie einen Scan hinzufügen können.
ibmcloud catalog offering version scc-apply [--instance-region REGION] [--scan SCAN] [--service-instance INSTANCE] [--target-account-name NAME] [--target-api-key KEY] [--timeout TIMEOUT] [--version-locator LOCATOR] [--wait WAIT]
Befehlsoptionen
- --instance-region REGION
- Die Region der Instanz.
- --scan SCAN
- Die ID eines Security and Compliance Center-Scans.
- --service-instance INSTANZ
- Geben Sie die Instanz-ID des Security and Compliance Center an.
- --target-account-name NAME (fakultativ)
- Geben Sie den Namen des Zielkontos an.
- --target-api-key KEY (fakultativ)
- Geben Sie einen API-Schlüssel an, wenn ein alternatives Konto (Zielkonto) zum Anwenden eines Scans auf Ihr Quellenkonto verwendet werden soll. Weitere Informationen finden Sie unter Zielkonto einrichten.
- --timeout TIMEOUT
- Geben Sie in Sekunden an, wie lange gewartet werden soll, bis der Scan auf die Version angewendet wird, bevor der Befehl zurückgegeben wird. Der Standardwert ist 600 (10 Minuten).
- --version-locator LOCATOR
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten. - --wait WAIT
- Warten Sie und verfolgen Sie den Fortschritt einer Scananwendung. Die Vorgabe ist true, wenn das Flag nicht angegeben wird. Wenn
true, verfolgt der Befehl den Fortschritt der Scan-Anwendung. Beifalsewird der Befehl sofort zurückgegeben.
ibmcloud catalog offering version scc-apply-status
Führen Sie den folgenden Befehl aus, um den Status einer Security and Compliance Center-Scananwendung für Ihre Version anzuzeigen.
ibmcloud catalog offering version scc-apply-status [--scan SCAN] [--version-locator LOCATOR]
Befehlsoptionen
- --scan SCAN
- Die ID eines Security and Compliance Center-Scans.
- --version-locator LOCATOR
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten.
ibmcloud-Katalog bietet Version get-scans
Führen Sie den folgenden Befehl aus, um die Security and Compliance Center-Scans abzurufen, die Ihrer Version hinzugefügt wurden.
ibmcloud catalog offering version get-scans [--instance-region REGION] [--output OUTPUT] [--profiles PROFILES] [--service-instance INSTANCE] [--target-account-name NAME] [--target-api-key KEY]
Befehlsoptionen
- --instance-region REGION
- Geben Sie die Region der Instanz an.
- --output OUTPUT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json. - --profiles PROFILE
- Geben Sie eine durch Kommas getrennte Liste mit Profilnamen mit Versionen an, z. B.
"IBM Cloud for Financial Services::1.2.0". - --service-instance INSTANZ
- Geben Sie die Instanz-ID des Security and Compliance Center an.
- --target-account-name NAME (fakultativ)
- Geben Sie den Namen des Zielkontos an.
- --target-api-key KEY (fakultativ)
- Geben Sie einen API-Schlüssel an, wenn ein alternatives Konto (Zielkonto) zum Anwenden eines Scans auf Ihr Quellenkonto verwendet werden soll. Weitere Informationen finden Sie unter Zielkonto einrichten.
ibmcloud catalog offering get-scan-ergebnisse
Führen Sie den folgenden Befehl aus, um einen Bericht über die Scan-Ergebnisse Ihrer Version des Code Risk Analyzer und Security and Compliance Center zu erstellen. Um einen vollständigen Bericht zu erstellen, müssen Sie die Code Risk Analyzer- und Security and Compliance Center ausführen.
ibmcloud catalog offering get-scan-results [--version-locator LOCATOR]
Befehlsoptionen
- --version-locator LOCATOR
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten.
ibmcloud catalog offering version create-draft
Führen Sie den folgenden Befehl aus, um einen Entwurf einer vorhandenen Version zu erstellen. Dieser Befehl ist nützlich, wenn Sie Änderungen an einer bestehenden Version vornehmen möchten, die veröffentlicht werden soll, ohne dass eine neue Version eingeführt werden muss. Bei einigen Änderungen, wie zum Beispiel bei einer Änderung der Quellendatei, ist die erneute Validierung des Produkts erforderlich.
ibmcloud catalog offering version create-draft --version-locator VERSION_NUMBER [--output FORMAT]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten. - --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json.
ibmcloud catalog offering version delete-version
Führen Sie den folgenden Befehl aus, um eine Version eines Produkts zu löschen.
ibmcloud catalog offering version delete-version --version-locator VERSION_NUMBER [--output FORMAT]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten. - --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json.
ibmcloud catalog offering version deprecate-version
Führen Sie den folgenden Befehl aus, um die Unterstützung einer zuvor veröffentlichten Produktversion aus dem IBM Cloud-Katalog zu entfernen.
ibmcloud catalog offering version deprecate-version --version-locator VERSION_NUMBER
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten.
ibmcloud catalog offering version refresh-version
Führen Sie den folgenden Befehl aus, um eine Änderung in der Quelldatei einer Entwurfsversion zu erstellen. Dieser Befehl ist zum Aktualisieren einer vorhandenen Version nützlich.
ibmcloud catalog offering version refresh-version --version-locator VERSION_NUMBER --zipurl URL [--include-config]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten. - --zipurl URL
- Die URL verweist auf die komprimierte Datei des Produkts.
- --include-config (optional)
- Wird diese Option angegeben, werden alle Konfigurationswerte einbezogen und sind beim Hinzufügen des Produkts verfügbar.
ibmcloud catalog offering version merge-draft
Führen Sie den folgenden Befehl aus, um eine Entwurfsversion eines Produkts zusammenzuführen.
ibmcloud catalog offering version merge-draft --version-locator VERSION_NUMBER
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten.
ibmcloud catalog offering ready
Führen Sie den folgenden Befehl aus, um Ihr Produkt für die gemeinsame Nutzung oder Veröffentlichung zu markieren.
ibmcloud catalog offering ready --version-locator VERSION_NUMBER
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für das Produkt abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und das jeweilige Produkt oder die Version suchen, die Sie verwenden möchten.
ibmcloud catalog offering delete
Führen Sie den folgenden Befehl aus, um ein Produkt aus Ihrem privaten Katalog zu löschen. Sie können ein Produkt, das im IBM Cloud-Katalog veröffentlicht ist, nicht löschen. Informationen zur Einstellung der Unterstützung eines veröffentlichten
Produkts aus dem IBM Cloud-Katalog finden Sie unter ibmcloud catalog offering deprecate-offering.
ibmcloud catalog offering delete --catalog CATALOG --offering OFFERING
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering publish account
Führen Sie den folgenden Befehl aus, um ein Produkt aus Ihrem privaten Katalog in einem Konto zu veröffentlichen. Nachdem das Produkt veröffentlicht wurde, haben die Benutzer des Kontos Zugriff auf den privaten Katalog. Die darin enthaltene Ressourcengruppe kann eine Instanz erstellen und in Betrieb nehmen.
ibmcloud catalog offering publish account [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering publish allowlist
Führen Sie den folgenden Befehl aus, um ein Produkt aus Ihrem privaten Katalog in einer Gruppe von Konten zu veröffentlichen, die in der Zulassungsliste aufgeführt sind. Nachdem das Produkt veröffentlicht wurde, können die Benutzer in den zugelassenen Konten eine Instanz erstellen und mit der Nutzung des Produkts beginnen.
ibmcloud catalog offering publish allowlist [--catalog CATALOG][--offering OFFERING][--account-ids ACCOUNT-IDS]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
- --account-ids ACCOUNT-IDS
- Die Konto-IDs.
ibmcloud catalog offering publish enterprise
Führen Sie den folgenden Befehl aus, um ein Produkt in einem Unternehmen zu veröffentlichen. Nach der Veröffentlichung des Produkts können Benutzer im Unternehmen eine Instanz des Produkts erstellen.
ibmcloud catalog offering publish enterprise [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering suspend-offering
Führen Sie den folgenden Befehl aus, um ein Produkt im Katalog auszusetzen. Sie können es für einen kurzen Zeitraum aussetzen, ohne es dauerhaft zu löschen oder die Unterstützung einzustellen. Das Sperren (Aussetzen) eines Produkts kann beispielsweise hilfreich sein, wenn Sie einen Fehler oder eine Sicherheitslücke in Ihrem Produkt entdeckt haben, die untersucht werden muss, bevor weitere Kunden das Produkt installieren.
ibmcloud catalog offering suspend-offering [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering version suspend-version
Führen Sie den folgenden Befehl aus, um eine Version eines Produkts im Katalog auszusetzen. Sie können die Version für kurze Zeit aussetzen, ohne sie dauerhaft zu löschen oder ihre Unterstützung einzustellen.
ibmcloud catalog offering version suspend-version [--version-locator VERSION_NUMBER]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für dieses Angebot abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und die Version lokalisieren, die Sie verwenden möchten.
ibmcloud catalog offering workspaces
Führen Sie den folgenden Befehl aus, um die Schematics-Arbeitsbereiche für eine Produktversion abzurufen.
ibmcloud catalog offering workspaces [--version-locator VERSION_NUMBER] [output FORMAT]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für dieses Angebot abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und die angegebene Version lokalisieren, die Sie verwenden möchten. - --output FORMAT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json.
ibmcloud catalog install
Führen Sie den folgenden Befehl aus, um eine Softwareversion aus dem IBM Cloud-Katalog zu installieren.
ibmcloud catalog install [--version-locator VERSION_NUMBER] [--cluster CLUSTER_ID] [--namespace NAME] [--override-values VALUES] [--timeout TIMEOUT] [--wait WAIT] [--workspace-name NAME] [--workspace-tags TAGS] [--workspace-tf-version VERSION] [--workspace-region REGION] [--workspace-rg-id ID] [schematics-delete VALUE]
Befehlsoptionen
- --version-locator VERSION_NUMBER
- Sie können den Versionshinweis für dieses Angebot abrufen, indem Sie den Befehl
ibmcloud catalog offering listausführen und die Version lokalisieren, die Sie verwenden möchten. - --cluster CLUSTER_ID
- Gibt den Clusternamen oder die Cluster-ID an.
- --namespace NAME
- Geben Sie den Namensbereich an, der verwendet werden soll.
- --override-values VALUES
- Geben Sie alle angepassten Konfigurationswerte für die Installation an. Sie können diesen Wert entweder in einer Zeile oder anhand einer JSON- oder TXT-Datei angeben. Beispiel:
override-values values.json. - --timeout TIMEOUT
- Geben Sie an, wie viele Sekunden der Arbeitsbereich Schematics auf die Installation wartet. Der Standardwert ist
180. - --wait WAIT
- Warten Sie und verfolgen Sie den Fortschritt des Arbeitsbereichsjobs Schematics. Wenn der Wert
trueangegeben ist, wird mit der Installation gewartet. Wennfalseangegeben ist, wird die Software sofort installiert. Der Standardwert isttrue. - --workspace-name NAME (optional)
- Einen Arbeitsbereichsnamen angeben. Der Standardwert ist
OfferingName-Date. - --workspace-tags TAGS (optional)
- Geben Sie eine durch Kommas getrennte Liste mit Tags an.
- --workspace-tf-version VERSION (optional)
- Geben Sie eine Terraform-Version des Arbeitsbereichs an.
- --workspace-region REGION (optional)
- Geben Sie eine Arbeitsbereichsregion an.
- --workspace-rg-id ID (optional)
- Geben Sie eine Ressourcengruppen-ID für den Arbeitsbereich an.
- --schematics-delete VALUE (optional)
- Geben Sie dieses Flag an, um den Arbeitsbereich Schematics nach der Validierung und Installation zu löschen.
Beispiel
Installieren Sie die Softwareversion 1 unter Verwendung von cluster A, namespace install und den Überschreibungswerten JSON values.json.
ibmcloud catalog install [--version-locator 1] [--cluster A] [--namespace install] [--override-values values.json]
Beispielformat für Überschreibungswerte in der Datei values.json:
{
"username": "install-test-1",
"password": "passw0rd"
}
Preise für ibmcloud-Katalog
Führen Sie den folgenden Befehl aus, um Preisinformationen für Katalogangebote abzurufen.
ibmcloud catalog pricing [-r, --region REGION] [-k, --kind KIND] [-p, --price PRICE] [--tag TAG] [--country COUNTRY] [--global] [--iam] [--json] [--csv] [-f, --file FILENAME]
Befehlsoptionen
- -r, --region (fakultativ)
- Nach Geo filtern.
- -k, --kind (fakultativ)
- Nach Ressourcentyp filtern. Derzeit werden
service(Standard),iaas,runtime,templateundgeographyunterstützt - -p, --price (fakultativ)
- Nach Preis filtern. Derzeit werden
free,paygoundsubscriptionunterstützt - -t, --tag (fakultativ)
- Nach Tag filtern. Dieses Flag ist wiederholt anwendbar und führt zu einem logischen OR aller angegebenen Tags.
- --co, --country (fakultativ)
- Nach Land filtern. Bei der Ausgabe nach CSV oder JSON kann der Wert
ALLverwendet werden, um Werte für alle Länder zu erhalten. - --json (optional)
- Ausgabe einer JSON-Antwort.
- --csv (fakultativ)
- Ausgabe einer CSV Datei.
- -f, --file (fakultativ)
- Geben Sie einen Dateinamen für die csv-Ausgabe an.
- --global (optional)
- Im globalen Geltungsbereich arbeiten.
- --iam (fakultativ)
- Nach IAM-kompatiblen Angeboten filtern.
Beispiel
Preisinformationen für Virtual Server for VPC für ein nutzungsabhängiges Konto abrufen.
ibmcloud catalog pricing is.instance [--price paygo]
ibmcloud-Katalog private Endpunkt-Regionen
Führen Sie den folgenden Befehl aus, um die Liste der Regionen abzurufen, die private Endpunkte für einen bestimmten Dienst unterstützen.
ibmcloud catalog private-endpoint regions [--service ID]
Befehlsoptionen
- --service
- Geben Sie die ID oder den programmatischen Namen des Dienstes an, um die Regionen anzuzeigen, die private Endpunkte unterstützen
ibmcloud-Katalog private Endpunktdienste
Führen Sie den folgenden Befehl aus, um die Liste der Dienste abzurufen, die private Endpunkte für eine bestimmte Region unterstützen.
ibmcloud catalog private-endpoint services [--region REGION]
Befehlsoptionen
- --region oder -r
- Geben Sie die REGION an, um zu sehen, welche Dienste private Endpunkte in dieser Region unterstützen
Dienstprogramm 'ibmcloud catalog' create-product-from-workspace
Führen Sie den folgenden Befehl aus, um eine Kachel für eine bereitstellbare Architektur aus einem Schematics-Arbeitsbereich zu erstellen, der direkt aus dem Repository Git erstellt wurde. Die einsatzfähige Architektur erzeugt ein Projekt, damit Sie die einsatzfähige Architektur mit der zukünftigen Version weiterentwickeln und pflegen können.
Für den Befehl ist die Umgebungsvariable GIT_TOKEN erforderlich, um sich mit Ihrem Quellenrepository zu authentifizieren, damit ein Katalogmanifest hinzugefügt werden kann. Der Befehl überträgt eine Push-Operation an eine neue Verzweigung
im Git-Repository, die sich im Arbeitsbereich Schematics befindet, und erstellt ein Release, das zum Onboarding verwendet wird.
ibmcloud catalog utility create-product-from-workspace [--workspace-id ID] [--api-key KEY] [--trusted-profile-id ID] [--catalog-label LABEL] [--offering-label LABEL] [--project-name NAME] [--project-resource-group GROUP] [--target-version VERSION] [--variation-label LABEL]
Befehlsoptionen
- --api-key oder --ak API KEY
- Geben Sie einen API-Schlüssel an, der verwendet wird, um den Katalog und das Projekt zu verknüpfen. Wechselseitig exklusiv mit '--trusted-profile-id'.
- --catalog-label KATALOG-Etikett (optional)
- Geben Sie die Bezeichnung eines vorhandenen Katalogs an, in den importiert werden soll, oder den Namen eines neu zu erstellenden Katalogs. Die Standardeinstellung ist "Migrierte DAs".
- --offering-label ANGEBOT-Etikett (optional)
- Geben Sie die Bezeichnung eines vorhandenen Angebots an, in das importiert werden soll, oder den Namen eines neu zu erstellenden Angebots. Der Standardwert ist 'Migrated <workspace_name>'. Die Bezeichnung überschreibt die vorhandene Angebotsbezeichnung, wenn der Arbeitsbereich aus einem Katalogangebot erstellt wird.
- --project-name NAME (fakultativ)
- Geben Sie einen Projektnamen an, der mit dem eingefügten Katalog verknüpft ist. Wenn das Projekt nicht existiert, wird es erstellt. Der Standardname ist "Dev Migration Project".
- --project-resource-group (fakultativ)
- Geben Sie eine Ressourcengruppe für das zu erstellende Projekt an. Die Standard-Ressourcengruppe ist "Standard".
- --target-version VERSION (fakultativ)
- Geben Sie die Zielversion für das migrierte Angebot an. Der Standardwert ist "1.0.0".
- --trusted-profile-id oder --tpi TRUSTED PROFILE ID
- Geben Sie eine vertrauenswürdige Profil-ID an, die verwendet wird, um den Katalog und das Projekt zu verknüpfen. Gegenseitig exklusiv mit '--api-key'.
- --variation-label VARIATIONSKENNZEICHEN (fakultativ)
- Geben Sie eine Variantenbezeichnung für die zu onboarding-Version an. Die Standardeinstellung ist "Standard". Die Bezeichnung überschreibt die vorhandene Versionsbezeichnung, wenn der Arbeitsbereich aus einem Katalogangebot erstellt wird.
- --workspace-id ARBEITSPLATZ-ID
- Geben Sie eine Arbeitsbereichs-ID für Schematics an. Um die Arbeitsbereichs-ID abzurufen, müssen Sie den Arbeitsbereich Schematics erstellen. Weitere Informationen finden Sie unter
ibmcloud schematics workspace new.
ibmcloud catalog utility netrc
Führen Sie den folgenden Befehl aus, um eine .netrc-Datei zu erstellen, den Maschinennamen in Ihrer .netrc-Datei zu erstellen oder den Berechtigungsnachweis in Ihrer .netrc-Datei zu aktualisieren. In einer
Datei .netrc-Datei werden die erforderlichen Anmeldeinformationen für die Verwendung von Terraform-Modulen aus dem IBM Cloud-Katalog gespeichert.
Mit diesem Befehl konfigurieren Sie eine Datei .netrc für den Rechnernamen cm.globalcatalog.cloud.ibm.com mit iamtoken als Benutzernamen und Ihrem IAM-Token als Passwort.
Sie benötigen Version 1.2.7 oder höher für das Plug-in für die Katalogverwaltungs-CLI, um den .netrc-Befehl ausführen zu können.
ibmcloud catalog utility netrc
ibmcloud catalog utility update-module-references
Führen Sie den folgenden Befehl aus, um die Terraform-Module Ihres Arbeitsverzeichnisses auf Aktualisierungen aus dem Katalog zu überprüfen und das Quellenattribut auf die neueste Version zu aktualisieren. Die README.md wurde ebenfalls aktualisiert.
ibmcloud catalog utility update-module-references
ibmcloud catalog offering unpublish account
Führen Sie den folgenden Befehl aus, um die Veröffentlichung eines Produkts in Ihrem Konto aufzuheben. Nachdem die Veröffentlichung des Produkts aufgehoben wurde, können Benutzer in Ihrem Konto keine Instanz des Produkts erstellen.
ibmcloud catalog offering unpublish account [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering unpublish allowlist
Führen Sie den folgenden Befehl aus, um Konto-IDs aus der Zulassungsliste des Produkts zu entfernen. Konten, die aus der Zulassungsliste entfernt werden, können keine Instanz des Produkts erstellen.
ibmcloud catalog offering unpublish allowlist [--catalog CATALOG][--offering OFFERING][--account-ids ACCOUNT-IDS]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
- --account-ids ACCOUNT-IDS
- Die Konto-IDs.
ibmcloud catalog offering unpublish enterprise
Führen Sie den folgenden Befehl aus, um die Veröffentlichung eines Produkts in einem Unternehmen zurücknehmen. Nachdem die Veröffentlichung des Produkts zurückgenommen wurde, kann das Unternehmen keine Instanz des Produkts erstellen.
ibmcloud catalog offering unpublish enterprise [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud katalogangebot unpublish ibm
Führen Sie den folgenden Befehl aus, um die Veröffentlichung eines Produkts von IBM aufzuheben. Nachdem das Produkt unveröffentlicht ist, können die Mitarbeiter von IBM keine Instanz des Produkts erstellen.
ibmcloud catalog offering unpublish ibm [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud-katalogangebot veröffentlichen ibm
Führen Sie den folgenden Befehl aus, um ein Angebot, das bereits in Ihrem Konto verfügbar ist, für alle IBM ers zu veröffentlichen. Bei diesem Teil des Veröffentlichungsprozesses wird eine Kachel in den Staging- und Produktionskatalogen erstellt, die nur für IBM ersichtlich ist. Durch die Veröffentlichung eines Angebots auf IBM können Sie das Angebot in der Produktion testen, bevor Sie es allen Benutzern im IBM Cloud Katalog zur Verfügung stellen.
ibmcloud catalog offering publish ibm [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering publish public
Führen Sie den folgenden Befehl aus, um Ihr privates Angebot im IBM Cloud-Katalog so zu veröffentlichen, dass es von allen Benutzern gesehen und genutzt werden kann. Um zu diesem Schritt im Veröffentlichungsprozess zu gelangen, müssen Sie das Angebot zunächst in Ihrem Konto und gegenüber allen IBM Mitarbeiterinnen und Mitarbeitern veröffentlichen, um den Testvorgang abzuschließen. Sie können diesen Befehl erst ausführen, nachdem die Testphase abgeschlossen ist.
Diese Option muss genehmigt werden. Sobald Ihre Freigabe abgeschlossen ist, steht Ihre Fliese allen Kunden von IBM Cloud zur Verfügung.
ibmcloud catalog offering publish public [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering deprecate-offering
Führen Sie den folgenden Befehl aus, um eine Version eines zuvor im IBM Cloud-Katalog veröffentlichten Angebots als veraltet zu kennzeichnen.
ibmcloud catalog offering deprecate-offering [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering restore-offering
Führen Sie den folgenden Befehl aus, um ein zuvor als veraltet gekennzeichnetes Produkt im IBM Cloud-Katalog wiederherzustellen. Nachdem Sie eine Version Ihres Produkts validiert haben, können Sie sie in dem veröffentlichten Status wiederherstellen, in dem sie sich befand, bevor sie als veraltet gekennzeichnet wurde.
ibmcloud catalog offering restore-offering [--catalog CATALOG][--offering OFFERING]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
ibmcloud catalog offering version restore-version
Führen Sie den folgenden Befehl aus, um eine zuvor als veraltet gekennzeichnete Version eines Produkts im IBM Cloud-Katalog wiederherzustellen. Durch die Wiederherstellung wird die Version in einen Entwurfszustand versetzt. Nach der Validierung können Sie die ursprüngliche Version wieder in den Veröffentlichungsstatus versetzen, in dem sie sich befand, bevor sie als veraltet gekennzeichnet wurde.
ibmcloud catalog offering version restore-version [--catalog CATALOG][--offering OFFERING] [--include-config]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --offering OFFERING
- Der Name oder die ID des Produkts.
- --include-config (optional)
- Wird diese Option angegeben, werden alle Konfigurationswerte einbezogen und sind beim Hinzufügen des Produkts verfügbar.
ibmcloud-katalogobjekt erstellen vpe
Führen Sie den folgenden Befehl aus, um ein Objekt zu einem privaten Katalog des Kontos hinzuzufügen.
ibmcloud catalog object create vpe [--catalog CATALOG] [--crn CRN] [endpoint-type TYPE] [--fqdn FQDN] [--name NAME] [--region REGION]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --crn CRN
- Geben Sie den Cloud Resource Name (CRN) an.
- --endpoint-type TYP
- Geben Sie den VPE-Endpunkttyp an.
- --fqdn FQDN
- Geben Sie eine durch Kommata getrennte Liste von voll qualifizierten Domänennamen an.
- --name NAME
- Geben Sie den Namen des Objekts an.
- --region REGION
- Geben Sie die Region für den VPE-Endpunkt an.
Objekt 'ibmcloud catalog' löschen
Führen Sie den folgenden Befehl aus, um das Objekt zu löschen.
ibmcloud catalog object delete [--catalog CATALOG] [--name NAME]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --name NAME
- Geben Sie den Namen des Objekts an.
Befehl 'ibmcloud catalog object update vpe'
Führen Sie den folgenden Befehl aus, um das Objekt zu aktualisieren.
ibmcloud catalog object update vpe [--catalog CATALOG] [--name NAME] [--crn CRN] [--endpoint-type TYPE] [--fqdn FQDN] [--region REGION]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --name NAME
- Geben Sie den Namen des Objekts an.
- --crn CRN (fakultativ)
- Geben Sie den Cloud Resource Name (CRN) an.
- --endpoint-type TYP (fakultativ)
- Geben Sie den VPE-Endpunkttyp an.
- --fqdn FQDN (wahlweise)
- Geben Sie eine durch Kommata getrennte Liste von voll qualifizierten Domänennamen an.
- --region REGION (optional)
- Geben Sie die Region für den VPE-Endpunkt an.
Objekt 'ibmcloud catalog' abrufen
Führen Sie den folgenden Befehl aus, um Informationen für ein bestimmtes Objekt abzurufen:
ibmcloud catalog object get [--catalog CATALOG] [--name NAME] [--output OUTPUT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --name NAME
- Geben Sie den Namen des Objekts an.
- --output OUTPUT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json
Objektliste für ibmcloud-Katalog
Führen Sie den folgenden Befehl aus, um eine Liste der Objekte in einem Katalog abzurufen.
ibmcloud catalog object list [--catalog CATALOG] [--output OUTPUT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --output OUTPUT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json
Objektsuche im ibmcloud-Katalog
Führen Sie den folgenden Befehl aus, um Objekte mithilfe der Lucene-Abfragesyntax zu suchen.
ibmcloud catalog object search [--query QUERY] [--output OUTPUT]
Befehlsoptionen
- --query ABFRAGE
- Geben Sie die Lucene-Abfragezeichenfolge an.
- --output OUTPUT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json
ibmcloud catalog object bereit
Führen Sie den folgenden Befehl aus, um Ihr Objekt als bereit zum Teilen oder Veröffentlichen zu markieren.
ibmcloud catalog object ready [--catalog CATALOG] [--name NAME]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --name NAME
- Geben Sie den Namen des Objekts an.
'ibmcloud catalog object publish'
Führen Sie den folgenden Befehl aus, um das Objekt in einer Zugriffsliste, in Ihrem Konto, in einem IBM-Katalog oder in einem IBM Cloud-Katalog zu veröffentlichen, damit alle Benutzer sie anzeigen und verwenden können.
ibmcloud catalog object publish COMMAND [--catalog CATALOG] [--name NAME]
Befehlsoptionen
- Befehl
- Geben Sie an, wo Sie das Objekt veröffentlichen möchten. Gültige Werte sind
accesslist,account,ibmoderpublic. - --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --name NAME
- Geben Sie den Namen des Objekts an.
Beispiel
Veröffentlichen Sie ein Objekt mit dem Namen dev-object im Katalog dev-catalog für IBM Mitarbeiter.
ibmcloud catalog object publish ibm --catalog dev-catalog --name dev-object
ibmcloud catalog object access-list add
Führen Sie den folgenden Befehl aus, um Konto-IDs zur Zugriffsliste eines Objekts hinzuzufügen.
ibmcloud catalog object access-list add [--account-id ID] [--catalog CATALOG] [--name NAME]
Befehlsoptionen
- --account-id ID
- Geben Sie eine kommagetrennte Liste von Konto-IDs an.
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --name NAME
- Geben Sie den Namen des Objekts an.
ibmcloud catalog object access-list get
Führen Sie den folgenden Befehl aus, um Informationen für eine bestimmte Zugriffsliste für ein Objekt abzurufen:
ibmcloud catalog object access-list get [--catalog CATALOG] [--name NAME] [--output OUTPUT]
Befehlsoptionen
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --name NAME
- Geben Sie den Namen des Objekts an.
- --output OUTPUT (optional)
- Gibt das Ausgabeformat an. Die Standardeinstellung ist terminal-kompatibel und die einzige unterstützte Alternative ist JSON. Beispiel:
--output json
ibmcloud catalog object access-list rm
Führen Sie den folgenden Befehl aus, um Konto-IDs aus der Zugriffsliste des Objekts zu entfernen.
ibmcloud catalog object access-list rm [--account-id ID] [--catalog CATALOG] [--name NAME]
Befehlsoptionen
- --account-id ID
- Geben Sie eine kommagetrennte Liste von Konto-IDs an.
- --catalog CATALOG
- Der Name oder die ID des Katalogs.
- --name NAME
- Geben Sie den Namen des Objekts an.